INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmc.label', 'keyword', 'de-DE', 'Schlüsselwort');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmc.label', 'title', 'de-DE', 'Titel');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '5', 'de-DE', 'Titel');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '14', 'de-DE', 'Titel');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('aba.name', 'title', 'de-DE', 'Titel');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('czifm.label', '1', 'de-DE', 'Titel');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmc.label', 'author', 'de-DE', 'Autor');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '51', 'de-DE', 'Autor');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '4', 'de-DE', 'Autor');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '13', 'de-DE', 'Autor');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('aba.name', 'author', 'de-DE', 'Autor');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('czifm.label', '2', 'de-DE', 'Autor');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '1', 'de-DE', 'Reihentitel');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '18', 'de-DE', 'ISBN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '2', 'de-DE', 'ISBN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '11', 'de-DE', 'ISBN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('vqbrad.description', '5', 'de-DE', 'ISBN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('czifm.label', '3', 'de-DE', 'ISBN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '19', 'de-DE', 'ISSN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '6', 'de-DE', 'ISSN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '15', 'de-DE', 'ISSN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('vqbrad.description', '6', 'de-DE', 'ISSN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('czifm.label', '4', 'de-DE', 'ISSN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '21', 'de-DE', 'ISMN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '23', 'de-DE', 'ISRC');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '27', 'de-DE', 'Interne ID');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('vqbrad.description', '11', 'de-DE', 'Interne ID');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '38', 'de-DE', 'Auflage');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('vqbrad.description', '14', 'de-DE', 'Auflage');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '40', 'de-DE', 'Verlag');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '7', 'de-DE', 'Verlag');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '16', 'de-DE', 'Verlag');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('vqbrad.description', '12', 'de-DE', 'Verlag');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cmf.label', '44', 'de-DE', 'Erscheinungsdatum');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '8', 'de-DE', 'Erscheinungsdatum');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '17', 'de-DE', 'Erscheinungsdatum');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('vqbrad.description', '13', 'de-DE', 'Erscheinungsdatum');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cnct.name', '1', 'de-DE', 'Taschenbuch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cit.name', '1', 'de-DE', 'Führerschein');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cit.name', '3', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('aurt.label', '6', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '555', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '807', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '880', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '901', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '964', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '977', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '987', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1000', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1569', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1589', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1602', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1614', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1626', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1638', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1648', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1657', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1752', 'de-DE', 'Sonstige');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '1', 'de-DE', '7_Tage_0_Verlängerung');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '2', 'de-DE', '28_Tage_2_Verlängerung');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '3', 'de-DE', '3_monate_0_verlängerung');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '4', 'de-DE', '3_Tage_1_Verlängerung');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '5', 'de-DE', '2_Monate_2_Verlängerung');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '6', 'de-DE', '35_Tage_1_Verlängerung');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '7', 'de-DE', '7_Tage_2_Verlängerung');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '8', 'de-DE', '1_Stunde_2_Verlängerung');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '9', 'de-DE', '28_Tage_0_Verlängerung');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crcd.name', '10', 'de-DE', '14_Tage_2_Verlängerung');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crrf.name', '2', 'de-DE', '10 Cent täglich');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('crrf.name', '3', 'de-DE', '10 Cent täglich');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccs.name', '0', 'de-DE', 'Verfügbar');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccs.name', '1', 'de-DE', 'Ausgeliehen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccs.name', '3', 'de-DE', 'Verloren');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccs.name', '4', 'de-DE', 'Fehlt');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccs.name', '6', 'de-DE', 'Im Transport');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccs.name', '14', 'de-DE', 'Beschädigt');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccs.name', '15', 'de-DE', 'Im Reservierungsregal');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cnal.name', '3', 'de-DE', 'Kein Zugriff');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.name', 'en-US', 'de-DE', 'Englisch (US)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.description', 'en-US', 'de-DE', 'Amerikanisches Englisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.name', 'cs-CZ', 'de-DE', 'Tschechisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.description', 'cs-CZ', 'de-DE', 'Tschechisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '98', 'de-DE', 'Tschechisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.name', 'en-CA', 'de-DE', 'Englisch (Kanada)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.description', 'en-CA', 'de-DE', 'Kanadisches Englisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.name', 'fi-FI', 'de-DE', 'Finnisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.description', 'fi-FI', 'de-DE', 'Finnisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '133', 'de-DE', 'Finnisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.name', 'fr-CA', 'de-DE', 'Französisch (Kanada)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.description', 'fr-CA', 'de-DE', 'Kanadisches Französisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.name', 'hy-AM', 'de-DE', 'Armenisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.description', 'hy-AM', 'de-DE', 'Armenisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'arm', 'de-DE', 'Armenisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.name', 'es-ES', 'de-DE', 'Spanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.description', 'es-ES', 'de-DE', 'Spanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '402', 'de-DE', 'Spanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.name', 'es-US', 'de-DE', 'Spanisch (US)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.description', 'es-US', 'de-DE', 'Mexikanisches Spanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.name', 'es-MX', 'de-DE', 'Spanisch (Mexiko)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.description', 'es-MX', 'de-DE', 'Mexikanisches Spanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.name', 'ru-RU', 'de-DE', 'Russisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('i18n_l.description', 'ru-RU', 'de-DE', 'Russisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '360', 'de-DE', 'Russisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '3', 'de-DE', 'LCCN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cza.label', '12', 'de-DE', 'LCCN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('czifm.label', '5', 'de-DE', 'LCCN');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('aout.opac_label', '1', 'de-DE', 'Überall');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('pgt.name', '1', 'de-DE', 'Benutzer');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('pgt.name', '3', 'de-DE', 'Mitarbeiter');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('pgt.name', '6', 'de-DE', 'Erwerbungen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('csg.label', 'acq', 'de-DE', 'Erwerbungen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('coust.label', 'circ.block_renews_for_holds', 'de-DE', 'Reservierungen: Verlängerung von Gegenständen, die für Reservierungen benötigt werden');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('coust.description', 'circ.max_fine.cap_at_price', 'de-DE', 'Dies hindert das System daran, mehr als den Einzelpreis in Verzugsgebühren zu berechnen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('vqbrad.description', '7', 'de-DE', 'Preis');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccpbt.label', 'misc', 'de-DE', 'Sonstiges');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccnbt.label', 'misc', 'de-DE', 'Sonstiges');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cbrebt.label', 'misc', 'de-DE', 'Sonstiges');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cubt.label', 'misc', 'de-DE', 'Sonstiges');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cubt.label', 'folks', 'de-DE', 'Freunde');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cubt.label', 'folks:circ.view', 'de-DE', 'Umläufe aktualisieren');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('cubt.label', 'folks:circ.renew', 'de-DE', 'Umläufe aktualisieren');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'aar', 'de-DE', 'Danakil-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'abk', 'de-DE', 'Abchasisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ace', 'de-DE', 'Aceh-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ach', 'de-DE', 'Acholi-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ada', 'de-DE', 'Adangme-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ady', 'de-DE', 'Adygisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'afh', 'de-DE', 'Afrihili (Künstliche Sprache)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'afr', 'de-DE', 'Afrikaans');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'aka', 'de-DE', 'Akan-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'akk', 'de-DE', 'Akkadisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'alb', 'de-DE', 'Albanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ale', 'de-DE', 'Aleutisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'alg', 'de-DE', 'Algonkin-Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'amh', 'de-DE', 'Amharisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ang', 'de-DE', 'Altenglisch (ca. 450-1100)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'apa', 'de-DE', 'Apachen-Sprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ara', 'de-DE', 'Arabisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'arc', 'de-DE', 'Aramäisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'arg', 'de-DE', 'Aragonesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'arp', 'de-DE', 'Arapaho-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'art', 'de-DE', 'Kunstsprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'arw', 'de-DE', 'Arawak-Sprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'asm', 'de-DE', 'Assamesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ath', 'de-DE', 'Athapaskische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'aus', 'de-DE', 'Australische Sprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ava', 'de-DE', 'Awarisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'ave', 'de-DE', 'Avestisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'awa', 'de-DE', 'Awadhi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'aym', 'de-DE', 'Aymará-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'aze', 'de-DE', 'Aserbeidschanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'bad', 'de-DE', 'Banda-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'bai', 'de-DE', 'Bamileke-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'bak', 'de-DE', 'Baschkirisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', 'bal', 'de-DE', 'Belutschisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '40', 'de-DE', 'Bambara-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '41', 'de-DE', 'Balinesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '42', 'de-DE', 'Baskisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '43', 'de-DE', 'Basaa-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '44', 'de-DE', 'Baltische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '46', 'de-DE', 'Weißrussisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '47', 'de-DE', 'Bemba-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '48', 'de-DE', 'Bengali');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '49', 'de-DE', 'Berbersprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '50', 'de-DE', 'Bhojpuri');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '51', 'de-DE', 'Bihari');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '52', 'de-DE', 'Bikol-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '53', 'de-DE', 'Edo-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '54', 'de-DE', 'Beach-la-mar');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '55', 'de-DE', 'Blackfoot-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '56', 'de-DE', 'Bantusprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '57', 'de-DE', 'Bosnisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '58', 'de-DE', 'Braj-Bhakha');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '59', 'de-DE', 'Bretonisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '60', 'de-DE', 'Batak-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '61', 'de-DE', 'Burjatisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '62', 'de-DE', 'Bugi-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '63', 'de-DE', 'Ungarisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '64', 'de-DE', 'Birmanische Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '65', 'de-DE', 'Caddo-Sprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '66', 'de-DE', 'Indianersprachen, Zentralamerika (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '67', 'de-DE', 'Kambodschanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '222', 'de-DE', 'Kambodschanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '68', 'de-DE', 'Karibische Sprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '69', 'de-DE', 'Katalanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '70', 'de-DE', 'Kaukasische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '71', 'de-DE', 'Cebuano');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '72', 'de-DE', 'Keltische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '73', 'de-DE', 'Chamorro-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '74', 'de-DE', 'Chibcha-Sprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '75', 'de-DE', 'Tschetschenisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '76', 'de-DE', 'Tschagataisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '77', 'de-DE', 'Chinesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '78', 'de-DE', 'Trukesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '440', 'de-DE', 'Trukesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '79', 'de-DE', 'Tscheremissisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '80', 'de-DE', 'Chinook-Jargon');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '81', 'de-DE', 'Choctaw-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '82', 'de-DE', 'Chipewyan-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '83', 'de-DE', 'Cherokee-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '84', 'de-DE', 'Kirchenslawisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '85', 'de-DE', 'Tschuwaschisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '86', 'de-DE', 'Cheyenne-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '87', 'de-DE', 'Cham-Sprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '88', 'de-DE', 'Koptisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '89', 'de-DE', 'Kornisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '90', 'de-DE', 'Korsisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '91', 'de-DE', 'Kreolisch-Englisch (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '92', 'de-DE', 'Kreolisch-Französisch (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '93', 'de-DE', 'Kreolisch-Portugiesisch (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '94', 'de-DE', 'Cree-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '95', 'de-DE', 'Krimtatarisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '96', 'de-DE', 'Kreolische Sprachen; Pidginsprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '97', 'de-DE', 'Kuschitische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '99', 'de-DE', 'Dakota-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '100', 'de-DE', 'Dänisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '101', 'de-DE', 'Darginisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '102', 'de-DE', 'Dajakisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '103', 'de-DE', 'Delaware-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '105', 'de-DE', 'Dogrib-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '106', 'de-DE', 'Dinka-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '107', 'de-DE', 'Maledivisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '108', 'de-DE', 'Dogri');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '109', 'de-DE', 'Drawidische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '110', 'de-DE', 'Duala-Sprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '111', 'de-DE', 'Mittelniederländisch (ca. 1050-1350)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '112', 'de-DE', 'Niederländisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '113', 'de-DE', 'Dyula-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '114', 'de-DE', 'Dzongkha');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '115', 'de-DE', 'Efik');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '116', 'de-DE', 'Ägyptisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '117', 'de-DE', 'Ekajuk');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '118', 'de-DE', 'Elamisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '119', 'de-DE', 'Englisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '120', 'de-DE', 'Mittelenglisch (1100-1500)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '121', 'de-DE', 'Esperanto');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '123', 'de-DE', 'Esperanto');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '122', 'de-DE', 'Eskimosprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '124', 'de-DE', 'Estnisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '125', 'de-DE', 'Äthiopisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '152', 'de-DE', 'Äthiopisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '126', 'de-DE', 'Ewe-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '127', 'de-DE', 'Ewondo');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '128', 'de-DE', 'Pangwe-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '129', 'de-DE', 'Färöisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '130', 'de-DE', 'Färöisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '131', 'de-DE', 'Fante-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '132', 'de-DE', 'Fidschi-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '134', 'de-DE', 'Finnougrische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '135', 'de-DE', 'Fon-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '136', 'de-DE', 'Französisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '137', 'de-DE', 'Friesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '140', 'de-DE', 'Friesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '138', 'de-DE', 'Mittelfranzösisch (ca. 1400-1600)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '139', 'de-DE', 'Altfranzösisch (ca. 842-1400)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '141', 'de-DE', 'Ful');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '142', 'de-DE', 'Friulisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '143', 'de-DE', 'Ga-Spache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '144', 'de-DE', 'Schottisches Gälisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '154', 'de-DE', 'Schottisches Gälisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '145', 'de-DE', 'Galicisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '156', 'de-DE', 'Galicisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '146', 'de-DE', 'Galla-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '328', 'de-DE', 'Galla-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '147', 'de-DE', 'Gayo-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '148', 'de-DE', 'Gbaya-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '149', 'de-DE', 'Germanische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '150', 'de-DE', 'Georgisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '151', 'de-DE', 'Deutsch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '153', 'de-DE', 'Gilbertesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '155', 'de-DE', 'Irisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '201', 'de-DE', 'Irisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '157', 'de-DE', 'Manx');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '275', 'de-DE', 'Manx');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '158', 'de-DE', 'Mittelhochdeutsch (ca. 1050-1500)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '159', 'de-DE', 'Althochdeutsch (ca. 750-1050)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '160', 'de-DE', 'Gondi-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '161', 'de-DE', 'Gorontalesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '162', 'de-DE', 'Gotisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '163', 'de-DE', 'Grebo-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '164', 'de-DE', 'Altgriechisch (bis 1453)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '165', 'de-DE', 'Modernes Griechisch (1453- )');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '166', 'de-DE', 'Guaraní-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '167', 'de-DE', 'Guaraní-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '168', 'de-DE', 'Gujariti-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '170', 'de-DE', 'Haida-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '172', 'de-DE', 'Haussa-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '173', 'de-DE', 'Hawaiisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '174', 'de-DE', 'Hebräisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '175', 'de-DE', 'Herero-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '176', 'de-DE', 'Hiligaynon-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '177', 'de-DE', 'Himachali');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '178', 'de-DE', 'Hindi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '179', 'de-DE', 'Hethitisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '180', 'de-DE', 'Miao-Sprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '181', 'de-DE', 'Hiri-Motu');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '182', 'de-DE', 'Ungarisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '183', 'de-DE', 'Hupa-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '184', 'de-DE', 'Iban-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '185', 'de-DE', 'Ibo-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '186', 'de-DE', 'Isländisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '187', 'de-DE', 'Ido');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '188', 'de-DE', 'Sichuan Yi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '189', 'de-DE', 'Ijo-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '190', 'de-DE', 'Inuktitut');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '191', 'de-DE', 'Interlingue');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '192', 'de-DE', 'Ilokano-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '193', 'de-DE', 'Interlingua (Internationale Hilfssprachen-Vereinigung)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '198', 'de-DE', 'Interlingua (Internationale Hilfssprachen-Vereinigung)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '194', 'de-DE', 'Indoarische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '195', 'de-DE', 'Indonesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '196', 'de-DE', 'Indogermanische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '197', 'de-DE', 'Inguschisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '199', 'de-DE', 'Inupik');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '200', 'de-DE', 'Iranische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '202', 'de-DE', 'Irokesische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '203', 'de-DE', 'Italienisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '204', 'de-DE', 'Javanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '205', 'de-DE', 'Japanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '206', 'de-DE', 'Jüdisch-Persisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '207', 'de-DE', 'Jüdisch-Arabisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '208', 'de-DE', 'Karakalpakisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '209', 'de-DE', 'Kabylisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '210', 'de-DE', 'Kachin-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '211', 'de-DE', 'Grönländisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '212', 'de-DE', 'Kamba-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '213', 'de-DE', 'Kannada');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '214', 'de-DE', 'Karenisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '215', 'de-DE', 'Kashmiri');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '216', 'de-DE', 'Kanuri-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '217', 'de-DE', 'Kawi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '218', 'de-DE', 'Kasachisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '219', 'de-DE', 'Kabardinisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '220', 'de-DE', 'Khasi-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '221', 'de-DE', 'Khoisan-Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '223', 'de-DE', 'Sakisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '224', 'de-DE', 'Kikuyu-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '225', 'de-DE', 'Rwanda-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '226', 'de-DE', 'Kirgisisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '227', 'de-DE', 'Kimbundu-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '228', 'de-DE', 'Konkani');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '229', 'de-DE', 'Komi-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '230', 'de-DE', 'Kongo-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '231', 'de-DE', 'Koreanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '233', 'de-DE', 'Kpelle-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '234', 'de-DE', 'Kru-Sprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '235', 'de-DE', 'Oraon-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '236', 'de-DE', 'Kwanyama-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '237', 'de-DE', 'Kumükisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '238', 'de-DE', 'Kurdisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '240', 'de-DE', 'Kutenai-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '241', 'de-DE', 'Judenspanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '242', 'de-DE', 'Lahndi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '243', 'de-DE', 'Lamba-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '244', 'de-DE', 'Okzitanisch (nach 1500)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '325', 'de-DE', 'Okzitanisch (nach 1500)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '245', 'de-DE', 'Laotisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '246', 'de-DE', 'Saamisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '389', 'de-DE', 'Saamisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '247', 'de-DE', 'Latein');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '248', 'de-DE', 'Lettisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '249', 'de-DE', 'Lesgisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '250', 'de-DE', 'Limburgisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '251', 'de-DE', 'Lingala');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '252', 'de-DE', 'Litauisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '253', 'de-DE', 'Mongo-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '254', 'de-DE', 'Rotse-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '255', 'de-DE', 'Luxemburgisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '256', 'de-DE', 'Lulua-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '257', 'de-DE', 'Luba-Katanga-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '258', 'de-DE', 'Ganda-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '259', 'de-DE', 'Luiseño-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '260', 'de-DE', 'Lunda-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '261', 'de-DE', 'Luo-Sprache (Kenia und Tansania)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '262', 'de-DE', 'Lushai-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '263', 'de-DE', 'Mazedonisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '266', 'de-DE', 'Marshallesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '267', 'de-DE', 'Maithili');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '268', 'de-DE', 'Makassarisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '269', 'de-DE', 'Malayalam');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '270', 'de-DE', 'Malinke-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '271', 'de-DE', 'Maori-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '272', 'de-DE', 'Austronesische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '273', 'de-DE', 'Marathi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '274', 'de-DE', 'Massai-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '276', 'de-DE', 'Malaiisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '277', 'de-DE', 'Mandaresisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '278', 'de-DE', 'Mende-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '279', 'de-DE', 'Mittelirisch (ca. 1100-1550)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '281', 'de-DE', 'Minangkabau-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '283', 'de-DE', 'Mon-Khmer-Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '284', 'de-DE', 'Malagassi-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '285', 'de-DE', 'Malagassi-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '286', 'de-DE', 'Maltesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '287', 'de-DE', 'Mandschurisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '288', 'de-DE', 'Meithei-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '289', 'de-DE', 'Manobo-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '290', 'de-DE', 'Mohawk-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '291', 'de-DE', 'Moldauisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '292', 'de-DE', 'Mongolisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '293', 'de-DE', 'Mossi-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '294', 'de-DE', 'Mehrere Sprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '295', 'de-DE', 'Mundasprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '296', 'de-DE', 'Muskogisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '298', 'de-DE', 'Maya-Sprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '299', 'de-DE', 'Nahuatl');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '300', 'de-DE', 'Indianersprachen, Nordamerika (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '301', 'de-DE', 'Neapel / Mundart');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '302', 'de-DE', 'Nauruanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '303', 'de-DE', 'Navajo-Spache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '304', 'de-DE', 'Ndebele-Sprache (Südafrika)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '305', 'de-DE', 'Ndebele-Sprache (Simbabwe)  ');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '306', 'de-DE', 'Ndonga');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '307', 'de-DE', 'Niederdeutsch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '308', 'de-DE', 'Nepali');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '309', 'de-DE', 'Newiri');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '310', 'de-DE', 'Nias-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '311', 'de-DE', 'Nigerkordofanische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '312', 'de-DE', 'Niue-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '313', 'de-DE', 'Norwegisch (Nynorsk)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '314', 'de-DE', 'Norwegisch (Bokmål)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '315', 'de-DE', 'Nogaisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '316', 'de-DE', 'Altnorwegisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '317', 'de-DE', 'Norwegisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '319', 'de-DE', 'Nubische Sprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '320', 'de-DE', 'Nyanja-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '321', 'de-DE', 'Nyamwezi-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '322', 'de-DE', 'Nkole-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '323', 'de-DE', 'Nyoro-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '324', 'de-DE', 'Nzima-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '326', 'de-DE', 'Ojibwa-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '327', 'de-DE', 'Oriya-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '329', 'de-DE', 'Osage-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '330', 'de-DE', 'Ossetisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '331', 'de-DE', 'Türkisch, Ottomanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '332', 'de-DE', 'Otomangue-Sprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '333', 'de-DE', 'Papuasprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '334', 'de-DE', 'Pangasinan-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '335', 'de-DE', 'Mittelpersisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '336', 'de-DE', 'Pampanggan-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '337', 'de-DE', 'Panjabi');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '338', 'de-DE', 'Papiamento');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '339', 'de-DE', 'Palau-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '340', 'de-DE', 'Altpersisch (ca. 600-400 v.Chr.)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '341', 'de-DE', 'Persisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '342', 'de-DE', 'Philippinen-Austronesisch (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '343', 'de-DE', 'Phönikisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '344', 'de-DE', 'Pali');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '345', 'de-DE', 'Polnisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '346', 'de-DE', 'Ponapeanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '347', 'de-DE', 'Portugiesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '348', 'de-DE', 'Prakrit');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '349', 'de-DE', 'Okzitanisch (bis 1500)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '351', 'de-DE', 'Quechua-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '352', 'de-DE', 'Rijasthini');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '353', 'de-DE', 'Osterinsel-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '354', 'de-DE', 'Rarotonganisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '356', 'de-DE', 'Rätoromanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '357', 'de-DE', 'Romani');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '358', 'de-DE', 'Rumänisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '359', 'de-DE', 'Rundi-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '361', 'de-DE', 'Sandawe-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '362', 'de-DE', 'Sango-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '363', 'de-DE', 'Jakutisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '364', 'de-DE', 'Indianersprachen, Südamerika (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '365', 'de-DE', 'Salish-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '366', 'de-DE', 'Samaritanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '367', 'de-DE', 'Sanskrit');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '368', 'de-DE', 'Samoanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '392', 'de-DE', 'Samoanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '369', 'de-DE', 'Sasak');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '370', 'de-DE', 'Santali');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '371', 'de-DE', 'Serbisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '372', 'de-DE', 'Schottisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '373', 'de-DE', 'Kroatisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '374', 'de-DE', 'Selkupisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '375', 'de-DE', 'Semitische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '376', 'de-DE', 'Altirisch (bis 1100)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '377', 'de-DE', 'Zeichensprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '378', 'de-DE', 'Schan-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '379', 'de-DE', 'Schona-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '394', 'de-DE', 'Schona-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '380', 'de-DE', 'Sidamo-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '381', 'de-DE', 'Singhalesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '396', 'de-DE', 'Singhalesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '382', 'de-DE', 'Sioux-Sprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '383', 'de-DE', 'Sinotibetische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '384', 'de-DE', 'Slawische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '385', 'de-DE', 'Slowakisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '386', 'de-DE', 'Slowenisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '387', 'de-DE', 'Südsaamisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '388', 'de-DE', 'Nordsaamisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '390', 'de-DE', 'Lulesaamisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '391', 'de-DE', 'Inarisaamisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '393', 'de-DE', 'Skoltsaamisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '395', 'de-DE', 'Sindhi-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '397', 'de-DE', 'Soninke-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '398', 'de-DE', 'Sogdisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '399', 'de-DE', 'Somali');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '400', 'de-DE', 'Songhai-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '401', 'de-DE', 'Süd-Sotho-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '406', 'de-DE', 'Süd-Sotho-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '403', 'de-DE', 'Sardisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '404', 'de-DE', 'Serer-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '405', 'de-DE', 'Nilosaharanische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '407', 'de-DE', 'Swasi-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '414', 'de-DE', 'Swasi-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '408', 'de-DE', 'Sukuma-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '409', 'de-DE', 'Sundanesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '410', 'de-DE', 'Susu');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '411', 'de-DE', 'Sumerisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '412', 'de-DE', 'Swahili');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '413', 'de-DE', 'Schwedisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '415', 'de-DE', 'Syrisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '416', 'de-DE', 'Tagalog');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '428', 'de-DE', 'Tagalog');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '417', 'de-DE', 'Tahitisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '418', 'de-DE', 'Thaisprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '419', 'de-DE', 'Tadschikisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '427', 'de-DE', 'Tadschikisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '420', 'de-DE', 'Tamil');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '421', 'de-DE', 'Tatarisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '422', 'de-DE', 'Tatarisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '423', 'de-DE', 'Telugu-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '424', 'de-DE', 'Temne-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '425', 'de-DE', 'Tereno-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '426', 'de-DE', 'Tetum-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '429', 'de-DE', 'Thailändisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '430', 'de-DE', 'Tibetisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '431', 'de-DE', 'Tigre-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '432', 'de-DE', 'Tigrinja-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '433', 'de-DE', 'Tiv-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '434', 'de-DE', 'Tokelauanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '435', 'de-DE', 'Tlingit-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '436', 'de-DE', 'Tamaseq');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '438', 'de-DE', 'Tongaisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '439', 'de-DE', 'Neumelanesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '441', 'de-DE', 'Tsimshian-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '442', 'de-DE', 'Tswana-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '444', 'de-DE', 'Tswana-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '443', 'de-DE', 'Tsonga-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '445', 'de-DE', 'Turkmenisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '446', 'de-DE', 'Tumbuka-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '447', 'de-DE', 'Tupi-Sprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '448', 'de-DE', 'Türkisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '449', 'de-DE', 'Altaische Sprachen (Andere)');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '451', 'de-DE', 'Twi-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '452', 'de-DE', 'Tuwinisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '453', 'de-DE', 'Udmurtisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '454', 'de-DE', 'Ugaritisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '455', 'de-DE', 'Uigurisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '456', 'de-DE', 'Ukrainisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '457', 'de-DE', 'Mbundu-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '458', 'de-DE', 'Unbestimmt');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '459', 'de-DE', 'Urdu');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '460', 'de-DE', 'Usbekisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '461', 'de-DE', 'Vai-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '462', 'de-DE', 'Venda-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '463', 'de-DE', 'Vietnamesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '464', 'de-DE', 'Volapük');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '465', 'de-DE', 'Wotisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '466', 'de-DE', 'Wakash-Sprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '467', 'de-DE', 'Walamo-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '468', 'de-DE', 'Waray');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '469', 'de-DE', 'Washo-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '470', 'de-DE', 'Walisisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '471', 'de-DE', 'Sorbisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '472', 'de-DE', 'Wallonisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '473', 'de-DE', 'Wolof-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '474', 'de-DE', 'Kalmückisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '475', 'de-DE', 'Xhosa-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '476', 'de-DE', 'Yao-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '477', 'de-DE', 'Yapesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '478', 'de-DE', 'Jiddisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '479', 'de-DE', 'Yoruba-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '480', 'de-DE', 'Yupik-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '481', 'de-DE', 'Zapotekisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '482', 'de-DE', 'Zenaga');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '483', 'de-DE', 'Zhuang');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '484', 'de-DE', 'Zande-Sprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '485', 'de-DE', 'Zulu-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '486', 'de-DE', 'Zuñi-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '488', 'de-DE', 'Vorschule');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '492', 'de-DE', 'Erwachsene');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '494', 'de-DE', 'Allgemein');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '495', 'de-DE', 'Jugendliche');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '509', 'de-DE', 'Computerdatei');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '513', 'de-DE', 'Dramen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '516', 'de-DE', 'Humor, Satire, etc.');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '518', 'de-DE', 'Kurzgeschichten');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '520', 'de-DE', 'Poesie');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '897', 'de-DE', 'Poesie');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1565', 'de-DE', 'Poesie');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1585', 'de-DE', 'Poesie');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '522', 'de-DE', 'Unbekannt');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '553', 'de-DE', 'Unbekannt');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '793', 'de-DE', 'Unbekannt');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '806', 'de-DE', 'Unbekannt');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '879', 'de-DE', 'Unbekannt');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '917', 'de-DE', 'Unbekannt');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '999', 'de-DE', 'Unbekannt');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1006', 'de-DE', 'Unbekannt');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '523', 'de-DE', 'Mikrofilm');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '903', 'de-DE', 'Mikrofilm');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '527', 'de-DE', 'Blindenschrift');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '565', 'de-DE', 'Blindenschrift');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '565', 'de-DE', 'Blindenschrift');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '589', 'de-DE', 'Blindenschrift');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '589', 'de-DE', 'Blindenschrift');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '611', 'de-DE', 'Blindenschrift');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '611', 'de-DE', 'Blindenschrift');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '908', 'de-DE', 'Blindenschrift');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '1792', 'de-DE', 'Blindenschrift');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '532', 'de-DE', 'Sammlung');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '572', 'de-DE', 'Mikrofilm');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '572', 'de-DE', 'Mikrofilm');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '594', 'de-DE', 'Mikrofilm');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '594', 'de-DE', 'Mikrofilm');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '618', 'de-DE', 'Mikrofilm');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '618', 'de-DE', 'Mikrofilm');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '665', 'de-DE', 'Verlag');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '885', 'de-DE', 'Dramen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1553', 'de-DE', 'Dramen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1573', 'de-DE', 'Dramen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1007', 'de-DE', 'Albanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1014', 'de-DE', 'Aserbeidschanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1058', 'de-DE', 'Kroatisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1074', 'de-DE', 'Delaware-Sprache');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1084', 'de-DE', 'Estnisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1086', 'de-DE', 'Äthiopisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1098', 'de-DE', 'Georgisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1112', 'de-DE', 'Deutsch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1115', 'de-DE', 'Hawaiisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1121', 'de-DE', 'Isländisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1127', 'de-DE', 'Indonesisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1151', 'de-DE', 'Litauisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1155', 'de-DE', 'Lettisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1172', 'de-DE', 'Mongolisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1197', 'de-DE', 'Nepali');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1202', 'de-DE', 'Nauruanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1232', 'de-DE', 'Serbisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1236', 'de-DE', 'Rumänisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1254', 'de-DE', 'Somali');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1264', 'de-DE', 'Syrisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1272', 'de-DE', 'Tokelauanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1275', 'de-DE', 'Tongaisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1308', 'de-DE', 'Samoanisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1323', 'de-DE', 'Mazedonisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1331', 'de-DE', 'Slowenisch');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.search_label', '1787', 'de-DE', 'Zeichensprachen');
INSERT INTO config.i18n_core (fq_field, identity_value, translation, string) VALUES ('ccvm.value', '1792', 'de-DE', 'Blindenschrift');
